/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package plugin

import "github.com/gin-gonic/gin"

type EmbedConfig struct {
	Platform string `json:"platform"`
	Enable   bool   `json:"enable"`
}

type Embed interface {
	Base
	GetEmbedConfigs(ctx *gin.Context) (embedConfigs []*EmbedConfig, err error)
}

var (
	// CallReviewer is a function that calls all registered parsers
	CallEmbed,
	registerEmbed = MakePlugin[Embed](false)
)
